DesktopDrop class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRawDropEventListener(
RawDropListener listener) → void -
init(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeRawDropEventListener(
RawDropListener listener) → void -
startAccessingSecurityScopedResource(
{required Uint8List bookmark}) → Future< bool> - macOS: Attempt to start security-scoped access for a bookmarked URL.
-
stopAccessingSecurityScopedResource(
{required Uint8List bookmark}) → Future< bool> - macOS: Stop security-scoped access previously started.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → DesktopDrop
-
final